==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sl.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Beležka",
    "The last viewed note cannot be accessed. " : "Do nazadnje pogledane zabeležke dostop ni mogoč.",
    "The notes folder is not accessible: %s" : "Mapa zabeležk ni dosegljiva: %s",
    "Error" : "Napaka",
    "New note" : "Nova zabeležka",
    "Distraction-free notes and writing" : "Enostavno beleženje in zapisovanje",
    "Settings" : "Nastavitve",
    "Deleted {title}" : "Izbrisano {title}",
    "Deleted {number} notes" : "Izbrisane zabeležke: {number} ",
    "Undo Delete" : "Razveljavi brisanje",
    "Please chose a valid path in {label} (bottom left corner)." : "Izbrati je treba veljavno pot oznake {label} (spodnji levi kot).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Zabeležke še niso shranjene. Če zapustite stran, bodo spremembe izgubljene!",
    "Folder to store your notes" : "Mapa za shranjevanje zabeležk",
    "path to notes" : "pot do mape",
    "File extension for new notes" : "Privzeta pripona datotek za nove zabeležke",
    "All notes" : "Vse zabeležke",
    "Categories" : "Kategorije",
    "No search result for “{search}” in {category}" : "Ni zadetkov iskanja za niz » {search} « v kategoriji {category}",
    "No search result for “{search}”" : "Ni zadetkov iskanja za niz » {search} «",
    "Loading …" : "Poteka nalaganje …",
    "Search result for “{search}” in {category}" : "Zadetki iskanja za niz » {search} « v kategoriji {category}",
    "Search result for “{search}”" : "Zadetki iskanja za niz » {search} «",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "This week" : "Ta teden",
    "Last week" : "Zadnji teden",
    "This month" : "Ta mesec",
    "Last month" : "Zadnji mesec",
    "Rename" : "Preimenuj",
    "Delete note" : "Izbriši beležko",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "Error during preparing note for deletion." : "Prišlo je do napake med pripravo zabeležke za brisanje.",
    "Empty note" : "Prazno sporočilo",
    "Write …" : "Zapisovanje ...",
    "Details" : "Podrobnosti",
    "Preview" : "Predogled",
    "Edit" : "Uredi",
    "Exit full screen" : "Končaj celozaslonski način",
    "Full screen" : "Celozaslonski način",
    "Save failed. Click to retry." : "Shranjevanje je spodletelo. Kliknite za ponovni poskus.",
    "Set category" : "Nastavi kategorijo",
    "Category" : "Kategorija",
    "Uncategorized" : "Neopredeljeno",
    "Click here to save manually" : "Kliknite za ročno shranjevanje",
    "Saving failed!" : "Shranjevanje je spodletelo!",
    "Last modified: {date}" : "Nazadnje spremenjeno: {date}",
    "Note has unsaved changes" : "V beležki so neshranjene spremembe.",
    "Subcategory" : "Podkategorija",
    "_%n word_::_%n words_" : ["%n beseda","%n besedi","%n besede","%n besed"],
    "Write down your thoughts without any distractions." : "Zapisovanje beležk brez vsakršnih motenj.",
    "Use Markdown markups to style your text." : "Za oblikovanje besedila je mogoče uporabiti jezik Markdown.",
    "Organize your notes in categories." : "Beležke je mogoče razvrstiti v kategorije.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Za dostop do beležk je na voljo tudi program za mobilne naprave.",
    "Android app" : "Odjemalec za Android",
    "iOS app" : "Odjemalec za iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Novo beležko je mogoče začeti s klikom na »{newnote}«.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podrejene kategorije je mogoče ustvariti z uporabo poševnice » / « kot ločila med nadrejeno in podrejeno kategorijo, na primer »{parent}/{sub}«.",
    "See JavaScript console and server log for details." : "Več podrobnosti je zbranih v konzoli JavaScript.",
    "Saving the note has failed due to insufficient storage." : "Shranjevanje zabeležke je spodletelo zaradi nezadostnega prostora.",
    "Updating settings has failed." : "Posodabljanje nastavitev je spodletelo.",
    "Fetching notes has failed." : "Pridobivanje zabeležk je spodletelo.",
    "Fetching note {id} has failed." : "Pridobivanje določila {id} sporočila je spodletelo.",
    "Creating new note has failed." : "Ustvarjanje nove zabeležke je spodletelo.",
    "Updating note {id} has failed." : "Posodabljanje določila {id} sporočila je spodletelo.",
    "Undo delete has failed for note {title}." : "Razveljavitev brisanja je za zabeležko {title} spodletelo.",
    "Deleting note {id} has failed." : "Brisanje določila {id} sporočila je spodletelo.",
    "Toggling favorite for note {id} has failed." : "Preklop oznake priljubljeno za beležko {id} je spodletelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Posodabljanje kategorije zabeležke je spodletelo. Ali ima ciljno mesto nastavljena ustrezna dovoljenja za zapisovanje?",
    "Updating the category for note {id} has failed." : "Posodabljanje kategorije za beležko {id} je spodletelo.",
    "Development Mode" : "Razvojni način",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Kaže, da je program nameščen in razvojne različice. Priporočena je namestitev iz uradne trgovine <a href=\"%1$s\">Nextcloud App Store</a>. Seveda lahko program izgradite tudi sami, upoštevajoč <a href=\"%2$s\">navodila za razvijalce</a>."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sl.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "Branje zabeležk z datotečnega sistema je spodletelo.",
    "Error" : "Napaka",
    "New note" : "Nova zabeležka",
    "Notes" : "Beležka",
    "Distraction-free notes and writing" : "Enostavno beleženje in zapisovanje",
    "Please see Nextcloud server log for details." : "Za več podrobnosti si oglejte dnevniški zapis strežnika Nextcloud.",
    "Deleted {title}" : "Izbrisano {title}",
    "Deleted {number} notes" : "Izbrisane zabeležke: {number} ",
    "Undo Delete" : "Razveljavi brisanje",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Zabeležke še niso shranjene. Če zapustite stran, bodo spremembe izgubljene!",
    "Settings" : "Nastavitve",
    "Folder to store your notes" : "Mapa za shranjevanje zabeležk",
    "path to notes" : "pot do mape",
    "File extension for new notes" : "Privzeta pripona datotek za nove zabeležke",
    "All notes" : "Vse zabeležke",
    "Categories" : "Kategorije",
    "No search result for “{search}” in {category}" : "Ni zadetkov iskanja za niz » {search} « v kategoriji {category}",
    "No search result for “{search}”" : "Ni zadetkov iskanja za niz » {search} «",
    "Loading …" : "Poteka nalaganje …",
    "Search result for “{search}” in {category}" : "Zadetki iskanja za niz » {search} « v kategoriji {category}",
    "Search result for “{search}”" : "Zadetki iskanja za niz » {search} «",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "This week" : "Ta teden",
    "Last week" : "Zadnji teden",
    "This month" : "Ta mesec",
    "Last month" : "Zadnji mesec",
    "Rename" : "Preimenuj",
    "Note's title" : "Naslov zabeležke",
    "Delete note" : "Izbriši beležko",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "Error during preparing note for deletion." : "Prišlo je do napake med pripravo zabeležke za brisanje.",
    "Empty note" : "Prazno sporočilo",
    "Write …" : "Zapisovanje ...",
    "Details" : "Podrobnosti",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Uredi",
    "Preview" : "Predogled",
    "Exit full screen" : "Končaj celozaslonski način",
    "Full screen" : "Celozaslonski način",
    "Save failed. Click to retry." : "Shranjevanje je spodletelo. Kliknite za ponovni poskus.",
    "Set category" : "Nastavi kategorijo",
    "Category" : "Kategorija",
    "Uncategorized" : "Neopredeljeno",
    "Click here to save manually" : "Kliknite za ročno shranjevanje",
    "Saving failed!" : "Shranjevanje je spodletelo!",
    "Last modified: {date}" : "Nazadnje spremenjeno: {date}",
    "Note has unsaved changes" : "V beležki so neshranjene spremembe.",
    "Subcategory" : "Podkategorija",
    "_%n word_::_%n words_" : ["%n beseda","%n besedi","%n besede","%n besed"],
    "_%n character_::_%n characters_" : ["%n znak","%n znaka","%nznaki","%n znakov"],
    "Write down your thoughts without any distractions." : "Zapisovanje beležk brez vsakršnih motenj.",
    "Use Markdown markups to style your text." : "Za oblikovanje besedila je mogoče uporabiti jezik Markdown.",
    "Organize your notes in categories." : "Beležke je mogoče razvrstiti v kategorije.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Za dostop do beležk je na voljo tudi program za mobilne naprave.",
    "Android app" : "Odjemalec za Android",
    "iOS app" : "Odjemalec za iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Novo beležko je mogoče začeti s klikom na »{newnote}«.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podrejene kategorije je mogoče ustvariti z uporabo poševnice » / « kot ločila med nadrejeno in podrejeno kategorijo, na primer »{parent}/{sub}«.",
    "Note not found." : "Zabeležke ni mogoče najti",
    "Note is locked." : "Zabeležka je zaklenjena.",
    "Insufficient storage." : "Nezadostna količina prostora.",
    "See JavaScript console and server log for details." : "Več podrobnosti je zbranih v konzoli JavaScript.",
    "Updating settings has failed." : "Posodabljanje nastavitev je spodletelo.",
    "Error from Nextcloud server: {msg}" : "Napaka s strežnika Nextcloud: {msg}",
    "Fetching notes has failed." : "Pridobivanje zabeležk je spodletelo.",
    "Fetching note {id} has failed." : "Pridobivanje določila {id} sporočila je spodletelo.",
    "Refreshing note {id} has failed." : "Osveževanje zabeležke {id} je spodletelo.",
    "Renaming note {id} has failed." : "Preimenovanje zabeležke {id} je spodletelo.",
    "Creating new note has failed." : "Ustvarjanje nove zabeležke je spodletelo.",
    "Saving note {id} has failed." : "Shranjevanje zabeležke {id} je spodletelo.",
    "Updating title for note {id} has failed." : "Posodabljanje naslova zabeležke {id} je spodletelo.",
    "Undo delete has failed for note {title}." : "Razveljavitev brisanja je za zabeležko {title} spodletelo.",
    "Deleting note {id} has failed." : "Brisanje določila {id} sporočila je spodletelo.",
    "Toggling favorite for note {id} has failed." : "Preklop oznake priljubljeno za beležko {id} je spodletelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Posodabljanje kategorije zabeležke je spodletelo. Ali ima ciljno mesto nastavljena ustrezna dovoljenja za zapisovanje?",
    "Updating the category for note {id} has failed." : "Posodabljanje kategorije za beležko {id} je spodletelo.",
    "Development Mode" : "Razvojni način",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Kaže, da je program nameščen in razvojne različice. Priporočena je namestitev iz uradne trgovine <a href=\"%1$s\">Nextcloud App Store</a>. Seveda lahko program izgradite tudi sami, upoštevajoč <a href=\"%2$s\">navodila za razvijalce</a>."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
